@@ -1,6 +1,6 @@
 
 /*
- *  $Id: defLex.c,v 3.6 2002/04/06 19:11:44 bkorb Exp $
+ *  $Id: defLex.c,v 3.8 2002/06/14 02:11:36 bkorb Exp $
  *  This module scans the template variable declarations and passes
  *  tokens back to the parser.
  */
@@ -126,22 +126,11 @@ scanAgain:
     case '#':
     {
         extern char* processDirective( char* );
-        char*  pz;
-
+        char* pz = processDirective( pCurCtx->pzScan+1 );
         /*
-         *  NB:  This character and all others that we treat specially
-         *       here must be disallowed as "OTHER_NAME" characters below
+         *  Ensure that the compiler doesn't try to save a copy of
+         *  "pCurCtx" in a register.  It must be reloaded from memory.
          */
-        pz = processDirective( pCurCtx->pzScan+1 );
-        /*
-         *  Advance past any leading blanks
-         */
-        while (isspace( *pz )) {
-            if (*pz == '\n')
-                pCurCtx->lineNo++;
-            pz++;
-        }
-
         pCurCtx->pzScan = pz;
         goto scanAgain;
     }
@@ -272,6 +261,7 @@ scanAgain:
             char* pz = strchr( pCurCtx->pzScan+2, '\n' );
             if (pz != NULL) {
                 pCurCtx->pzScan = pz+1;
+                pCurCtx->lineNo++;
                 goto scanAgain;
             }
             break;
@@ -657,6 +647,7 @@ assembleHereString( char* pzScan )
         for (;;) {
             switch (*(pzDest++) = *(pzScan++)) {
             case '\n':
+                pCurCtx->lineNo++;
                 goto lineDone;
 
             case NUL:
