@@ -1,6 +1,6 @@
 
 /*
- *  $Id: defReduce.c,v 3.4 2002/01/19 07:35:23 bkorb Exp $
+ *  $Id: defReduce.c,v 3.7 2002/06/15 18:24:59 bkorb Exp $
  *  Parse Reduction processing routines
  */
 
@@ -66,6 +66,7 @@ unloadDefs( void )
 }
 #endif
 
+
 STATIC tDefEntry*
 getEntry( void )
 {
@@ -231,7 +232,7 @@ makeMacroList(
      */
     while (ct-- > 0) {
         pNewDE->pTwin =
-            (tDefEntry*)findPlace( twinName, NULL );
+            (tDefEntry*)findPlace( (YYSTYPE)twinName, (YYSTYPE)NULL );
         pNewDE = pNewDE->pTwin;
         pNewDE->pzValue = pL->entries[ ct ];
         pNewDE->valType = type;
@@ -302,6 +303,18 @@ findPlace(
 }
 
 
+EXPORT YYSTYPE
+makeEmptyDefs( void )
+{
+    tSCC   zBogus[] = "@BOGUS@";
+    static tDefEntry de = {
+        NULL, NULL, NULL, NULL, (char*)zBogus, VALTYP_TEXT, 0,
+        (char*)(zBogus + sizeof( zBogus ) - 1) };
+    rootDefCtx.pDefs = &de;
+    return (YYSTYPE)(&de);
+}
+
+
 EXPORT YYSTYPE
 identify( YYSTYPE template )
 {
