@@ -1,6 +1,6 @@
 /* -*- buffer-read-only: t -*- vi: set ro:
  *
- * AutoGen Globally exported prototypes Sun May 12 08:56:24 PDT 2002
+ * AutoGen Globally exported prototypes Sun Jun 16 10:55:49 PDT 2002
  */
 #ifndef AUTOGEN_PROTOTYPES_H
 #define AUTOGEN_PROTOTYPES_H
@@ -102,6 +102,8 @@ findPlace(
         YYSTYPE name,
         YYSTYPE index );
 YYSTYPE
+makeEmptyDefs( void );
+YYSTYPE
 identify( YYSTYPE template );
 
 /* exports from expOutput.c */
